@@ -30,26 +30,26 @@
 #include "mainwindow.h"
 #include "bovo_version.h"
 
-static const char description[] = I18N_NOOP("KDE Five in a Row Board Game");
-static const char copyleft[] = I18N_NOOP("(c) 2002-2007, Aron Boström");
-
 using namespace gui;
 
 int main(int argc, char **argv) {
 
     // Fixes blurry icons with fractional scaling
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("bovo"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("bovorc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("bovoui.rc"));
     migrate.migrate();
-
+#endif
     KLocalizedString::setApplicationDomain("bovo");
 
     KAboutData aboutData(QStringLiteral("bovo"), i18n("Bovo"),
-            QStringLiteral(BOVO_VERSION_STRING), i18n(description), KAboutLicense::GPL,
-            i18n(copyleft), QString(), QStringLiteral("https://kde.org/applications/games/org.kde.bovo"));
+            QStringLiteral(BOVO_VERSION_STRING), i18n("KDE Five in a Row Board Game"), KAboutLicense::GPL,
+            i18n("(c) 2002-2007, Aron Boström"), QString(), QStringLiteral("https://kde.org/applications/games/org.kde.bovo"));
     aboutData.addAuthor(i18n("Aron Boström"),i18n("Author"),
                         QStringLiteral("aron.bostrom@gmail.com"));
 
@@ -68,7 +68,7 @@ int main(int argc, char **argv) {
     if( app.isSessionRestored() ) {
         kRestoreMainWindows<MainWindow>();
     } else {
-        MainWindow *mainWin = new MainWindow();
+        auto mainWin = new MainWindow();
         mainWin->show();
     }
 
